@@ -5,9 +5,9 @@ from typing import List, Union
 from pathlib import Path
 
 
-__version__ = "2023.3.27.1"
+__version__ = "2025.7.15.1"
 log_format = logging.Formatter(
-    "[%(asctime)s] %(filename)s/%(lineno)s/%(funcName)s/%(levelname)s: %(message)s"
+    "[%(asctime)s] %(name)s/%(filename)s/%(lineno)s/%(funcName)s/%(levelname)s: %(message)s"
 )
 
 # 日志句柄
@@ -23,8 +23,58 @@ if len(logger.handlers) == 0:
     logger.addHandler(console_handler)
 
 
+def clean_repeat_handler():
+    """清理重复的日志handler"""
+    from deng.utils import get_caller_info
+    _info = get_caller_info(2)
+    logger.debug(f"调用来源：{_info['output']}")
+
+    logger.debug(f"开始清理重复的日志句柄：{logger.handlers}")
+
+    _first_console = False
+    # 收集已有的 FileHandler 处理器输出文件路径列表
+    log_file_set = set()
+    for _handler in logger.handlers:
+        if isinstance(_handler, logging.FileHandler):
+            if _handler.baseFilename in log_file_set:
+                _handler.flush()
+                _handler.close()
+                logger.removeHandler(_handler)
+                logger.debug(f"关闭重复的：{_handler}")
+            else:
+                log_file_set.add(_handler.baseFilename)
+        elif isinstance(_handler, logging.StreamHandler):
+            # 对于StreamHandler实例，仅保留一个，防止越积越多
+            if _first_console is False:
+                _first_console = True
+                logger.debug(f"保留：{_handler}")
+            else:
+                _handler.flush()
+                _handler.close()
+                logger.removeHandler(_handler)
+                logger.debug(f"关闭：{_handler}")
+        else:
+            logger.debug(f"忽略：{_handler}")
+
+
+def close_all_handler():
+    """关闭所有日志handler"""
+    from deng.utils import get_caller_info
+    _info = get_caller_info(2)
+    logger.debug(f"调用来源：{_info['output']}")
+
+    for handler in logger.handlers:
+        handler.flush()
+        handler.close()
+        logger.removeHandler(handler)
+
+
 def clean_handler(close_console_handler: bool = False):
     """清理日志handler，关闭所有FileHandler实例，StreamHandler实例只保留一个"""
+    from deng.utils import get_caller_info
+    _info = get_caller_info(2)
+    logger.debug(f"调用来源：{_info['output']}")
+
     _first_console = False
     logger.debug(f"开始清理日志句柄：{logger.handlers}")
     for _handler in logger.handlers:
@@ -55,12 +105,12 @@ def clean_handler(close_console_handler: bool = False):
 
 
 def configure_logger(
-    level: int,
+    level: int = None,
     handlers: List[logging.Handler] = None,
     log_file: Union[Path, str] = None,
     append: bool = True,
     caller_info: dict = None,
-    unify_level: bool = True,
+    unify_level: bool = False,
     fmt: logging.Formatter = None,
 ):
     """配置日志处理器
@@ -77,7 +127,9 @@ def configure_logger(
     logger.debug(f"调用来源：{_info['output']}")
 
     # 设置主句柄日志级别
-    if level in (
+    if level is None:
+        pass
+    elif level in (
         logging.NOTSET,
         logging.DEBUG,
         logging.INFO,
@@ -105,7 +157,7 @@ def configure_logger(
             handler.setFormatter(fmt)
 
     # 各Handler与Logger采用统一的level级别
-    if unify_level:
+    if isinstance(level, int) and unify_level:
         for handler in logger.handlers:
             handler.setLevel(level)
 
@@ -134,7 +186,7 @@ def configure_logger(
                 if new_console_handler:
                     logger.addHandler(handler)
                     # 各Handler与Logger采用统一的level级别
-                    if unify_level:
+                    if isinstance(level, int) and unify_level:
                         handler.setLevel(level)
                 else:
                     logger.debug(f"StreamHandler 类型处理器已经存在（控制台只保留一个），忽略：{handler}")
@@ -147,14 +199,14 @@ def configure_logger(
                     continue
                 else:
                     # 各Handler与Logger采用统一的level级别
-                    if unify_level:
+                    if isinstance(level, int) and unify_level:
                         handler.setLevel(level)
                     logger.addHandler(handler)
                     log_file_list.append(str(handler.baseFilename))
             elif isinstance(handler, logging.Handler):
                 # logger.warning(f"忽略日志Handler：{handler}")
                 # 各Handler与Logger采用统一的level级别
-                if unify_level:
+                if isinstance(level, int) and unify_level:
                     handler.setLevel(level)
                 logger.addHandler(handler)
             else:
