@@ -1,3 +1,4 @@
+import jwt
 import base64
 import hashlib
 from Crypto.Cipher import AES
@@ -34,7 +35,14 @@ def md5sum(*, _file_path: str = None, _string: str = None):
     if _file_path:
         check_path_is_exits(_file_path, path_type="file")
         with open(_file_path, "rb") as _file:
-            return hashlib.md5(_file.read()).hexdigest()
+            # 每次读取8192个字节，防止文件过大导致内存溢出
+            md5 = hashlib.md5()
+            while True:
+                chunk = _file.read(8192)
+                if not chunk:
+                    break
+                md5.update(chunk)
+            return md5.hexdigest()
 
     if _string:
         m = hashlib.md5()
@@ -54,7 +62,38 @@ def md5_str(target):
     return md5sum(_string=target)
 
 
+def jwt_decode(
+    jwt_token: str,
+    verify_signature: bool = False,
+    verify_exp: bool = False,
+    verify_nbf: bool = False,
+    verify_iat: bool = False,
+    verify_aud: bool = False,
+    verify_iss: bool = False,
+    **kwargs,
+) -> dict:
+    """解析 JWT Token"""
+    return jwt.decode(
+        jwt_token,
+        algorithms=["HS256"],
+        options={
+            "verify_iss": verify_iss,
+            "verify_aud": verify_aud,
+            "verify_iat": verify_iat,
+            "verify_nbf": verify_nbf,
+            "verify_exp": verify_exp,
+            "verify_signature": verify_signature,
+            **kwargs,
+        },
+    )
+
+
 class MyCrypto(object):
+    """RSA加密算法特性：
+    1. 公钥加密，私钥解密；
+    2. 公钥相同，明文相同，但每次加密后得到的密文不同；
+    """
+
     @classmethod
     def encrypt(cls, data, xsrf_token=None, old_secret=None) -> str:
         """加密"""
@@ -124,14 +163,19 @@ class MyCrypto(object):
         pub_key = f"-----BEGIN PUBLIC KEY-----\n{key}\n-----END PUBLIC KEY-----"
         pub_key = RSA.importKey(str(pub_key))
         cipher = oaep_cipher.new(pub_key, hashAlgo=SHA256)
-        rsa_text = base64.b64encode(cipher.encrypt(data.encode('utf-8')))
-        return rsa_text.decode('utf-8')
+        rsa_text = base64.b64encode(cipher.encrypt(data.encode("utf-8")))
+        return rsa_text.decode("utf-8")
 
     @staticmethod
     def rsa_decrypt(key, data):
         """RSA非对称解密，用于通过用户名与密码创建新用户时"""
-        pri_key = "-----BEGIN RSA PRIVATE KEY-----\n" + key + "\n" + "-----END RSA PRIVATE KEY-----"
+        pri_key = (
+            "-----BEGIN RSA PRIVATE KEY-----\n"
+            + key
+            + "\n"
+            + "-----END RSA PRIVATE KEY-----"
+        )
         pri_key = RSA.import_key(pri_key)
         cipher = oaep_cipher.new(pri_key, hashAlgo=SHA256)
         rsa_text = cipher.decrypt(base64.b64decode(data))
-        return rsa_text.decode('utf-8')
+        return rsa_text.decode("utf-8")
