@@ -37,8 +37,9 @@ def check_branch_exist(
             return True
     else:
         try:
+            # 末尾添加--防止分支名与文件名称冲突
             utils.execute_cmd(
-                ["git", "checkout", branch], level="debug", ignore_error_log=True
+                ["git", "checkout", branch, "--"], level="debug", ignore_error_log=True
             )
         except Exception as e:
             logger.debug(f"【{repo_path}】本地库中不存在【{branch}】分支")
@@ -231,7 +232,7 @@ def pull_repo(
         branch_exist = check_branch_exist(repo_path, branch, remote=remote)
         if branch_exist:
             # 远程分支存在时——判断分支是否存在时已经拉取过更新了，不再重复拉取
-            utils.execute_cmd(["git", "checkout", branch], level="debug")
+            utils.execute_cmd(["git", "checkout", branch, "--"], level="debug")
             utils.execute_cmd(["git", "merge"], level="debug")
         else:
             # 远程库只读
@@ -247,7 +248,7 @@ def pull_repo(
                 if no_exist_create_modle and no_exist_create_modle != branch:
                     # 本地不存在时基于模板分支创建指定分支
                     utils.execute_cmd(["git", "branch", branch, no_exist_create_modle])
-                    utils.execute_cmd(["git", "checkout", branch])
+                    utils.execute_cmd(["git", "checkout", branch, "--"])
                     utils.execute_cmd(["git", "push", "-u", remote, branch])
                 else:
                     raise ValueError(f"库{repo_name}远程分支不存在：{branch}")
@@ -279,7 +280,7 @@ def pull_repo(
             # 冲突后删除本地重新从远程拉取
             utils.execute_cmd(["git", "tag", "-d", branch], level="info")
             utils.execute_cmd(["git", "fetch", remote, "tag", branch], level="info")
-        utils.execute_cmd(["git", "checkout", branch], level="debug")
+        utils.execute_cmd(["git", "checkout", branch, "--"], level="debug")
     elif branch_type == "commit":
         # 先检查本地是否已经为预计目标，如果是则不用访问远程git服务，防止远程git服务不可用导致额外的报错
         # 只适用于commit类型，因为只有commit是不可变的，branch是可变的，tag可以删除后重新创建同名标签
@@ -292,7 +293,24 @@ def pull_repo(
             logger.info(f"当前已经是预定目标，无需切换：{branch_type}:{branch}:{repo_path}")
         else:
             utils.execute_cmd(["git", "fetch", remote, default_branch], level="debug")
-            utils.execute_cmd(["git", "checkout", branch], level="debug")
+            _count = 2
+            while _count > 0:
+                _count -= 1
+                try:
+                    utils.execute_cmd(["git", "checkout", branch, "--"], level="debug")
+                except Exception as _err:
+                    logger.exception(_err)
+                    logger.warning(f"执行命令失败，重试1次")
+                    # 有可能 default_branch 分支上有过强制回滚，导致分支上没有此commit从而导致报错，pull一次可避免
+                    # 此命令为返回1，必须捕获异常，否则会当成执行失败
+                    try:
+                        utils.execute_cmd(["git", "pull"], level="debug")
+                    except Exception as _e:
+                        pass
+                    if _count <= 0:
+                        raise _err
+                else:
+                    break
     else:
         raise ValueError(f"库{repo_name}目标类型错误，必须为branch,tag,commit中的一种")
 
@@ -419,8 +437,47 @@ def create_branch_by_tag(
         # 开始创建新分支
         utils.execute_cmd(["git", "branch", branch_name, tag_name])
     # 切换到新分支
-    utils.execute_cmd(["git", "checkout", branch_name])
+    utils.execute_cmd(["git", "checkout", branch_name, "--"])
     if push:
         # 将新分支推送到远程库
         utils.execute_cmd(["git", "push", "-u", "origin", branch_name])
     return True
+
+
+def delete_branch(
+    repo_path: Union[str, Path], branch_name: str, remote: str = "origin"
+) -> bool:
+    """删除分支
+    :param repo_path: git库本地绝对路径
+    :param branch_name: 新分支名称
+    :param remote: 远程库名称
+    """
+    repo_path = Path(repo_path)
+
+    file.check_path_is_exits(repo_path, path_type="dir")
+    os.chdir(repo_path)
+
+    # 清空工作区所有的变更
+    utils.execute_cmd(["git", "checkout", "."], level="debug")
+    # 丢弃本地新增与删除的
+    utils.execute_cmd(["git", "clean", "-dfx"], level="debug")
+
+    try:
+        # 切换到待删除分支
+        utils.execute_cmd(["git", "fetch", remote, branch_name])
+        utils.execute_cmd(["git", "checkout", branch_name, "--"])
+
+        # 切换到master分支
+        utils.execute_cmd(["git", "fetch", remote, "master"])
+        utils.execute_cmd(["git", "checkout", "master", "--"])
+
+        # 删除本地目标分支
+        utils.execute_cmd(["git", "branch", "-D", branch_name])
+
+        # 删除远程目标分支
+        utils.execute_cmd(["git", "push", remote, "--delete", branch_name])
+    except Exception as _error:
+        logger.error(f"删除分支失败：{_error}")
+        return False
+    else:
+        return True
