@@ -1,6 +1,8 @@
 import time
 import math
+import pytz
 import datetime
+from typing import Union
 
 
 def get_timestamp(length: int = 10, utc=False) -> int:
@@ -15,7 +17,7 @@ def get_timestamp(length: int = 10, utc=False) -> int:
 
 def get_current_time(
     _format: str = "long", offset: int = 0, sep1="-", sep2=":", **kwargs
-):
+) -> str:
     if not isinstance(offset, int):
         raise ValueError(f"offset参数非法，预期为int类型，实际为{type(offset)}")
 
@@ -31,7 +33,9 @@ def get_current_time(
         return target_time.strftime(_format)
 
 
-def str_to_time(time_str: str, _format="long"):
+def str_to_time(
+    time_str: str, _format="long"
+) -> Union[datetime.datetime, datetime.date]:
     if not time_str:
         raise ValueError(f"time_str参数非法：{time_str}")
 
@@ -42,19 +46,30 @@ def str_to_time(time_str: str, _format="long"):
         return day.date()
 
 
-def time_to_str(_time: datetime.datetime, _format="long"):
+def time_to_str(_time: datetime.datetime, _format="long") -> str:
     if _format == "long":
         return _time.strftime("%Y-%m-%d %H:%M:%S")
     else:
         return _time.strftime("%Y-%m-%d")
 
 
-def timestamp_to_str(timestamp: int, fmt="%Y-%m-%d %H:%M:%S"):
+def timestamp_to_str(
+    timestamp: int, fmt="%Y-%m-%d %H:%M:%S", tz: str = "Asia/Shanghai"
+) -> str:
     """时间戳转换时间字符串"""
     if len(str(timestamp)) == 13:
-        current_time = math.floor(int(timestamp) / 1000)
-        return time.strftime(fmt, time.localtime(current_time))
+        time_int = math.floor(int(timestamp) / 1000)
     elif len(str(timestamp)) == 10:
-        return time.strftime(fmt, time.localtime(int(timestamp)))
+        time_int = int(timestamp)
     else:
         raise ValueError(f"时间戳格式错误：{timestamp}")
+
+    utc_time = datetime.datetime.fromtimestamp(time_int, tz=pytz.UTC)
+    target_time = utc_time.astimezone(pytz.timezone(tz))
+    return target_time.strftime(fmt)
+
+
+def str_to_timestamp(time_str: str, fmt: str) -> float:
+    """时间字符串转换时间戳"""
+    time_obj = datetime.datetime.strptime(time_str, fmt)
+    return time_obj.timestamp()
