@@ -1,4 +1,5 @@
 """工具函数，与打包逻辑无直接关联"""
+import math
 # coding = utf-8
 import os
 import uuid
@@ -140,6 +141,13 @@ class MyJSONEncoder(json.encoder.JSONEncoder):
         return my_json_serializable(o)
 
 
+def json_to_str(content, indent: int = 4) -> str:
+    try:
+        return json.dumps(content, ensure_ascii=False, indent=4, cls=MyJSONEncoder)
+    except Exception as _error:
+        return str(content)
+
+
 def byte_to_str(src, encoding=None) -> str:
     if isinstance(src, bytes):
         error_list = []
@@ -306,3 +314,19 @@ def get_caller_desc(depth: int) -> str:
     except Exception as err:
         logger.exception(err)
         return ""
+
+
+def get_excel_col_name_by_index(col_index: int) -> str:
+    """根据列索引获取Excel中的列名"""
+    if col_index <= 0:
+        raise ValueError("Excel列索引号为从1开始的正整数")
+
+    if 0 < col_index <= 26:
+        return chr(col_index + 64)
+    else:
+        quotient = math.floor(col_index / 26)
+        remainder = col_index % 26
+        if remainder == 0:
+            return get_excel_col_name_by_index(quotient - 1) + "Z"
+        else:
+            return get_excel_col_name_by_index(quotient) + chr(remainder + 64)
