@@ -150,17 +150,17 @@ def is_running_as_admin() -> bool:
         return False
 
 
-def get_current_app_list(detail=False, win_rm_session=None) -> list:
+def get_current_app_list(detail=False, win_rm_session=None, timeout: int = 60) -> list:
     """获取当前用户实时app列表"""
     cmd_text = 'tasklist /nh /fo csv /fi "SESSION ne 0"'
     if detail:
         cmd_text += " /v"
 
     if win_rm_session:
-        _res = win_rm_session.run_cmd(cmd_text)
+        _res = win_rm_session.run_cmd(cmd_text, timeout=timeout)
         out_decode = bytes_to_str(_res.std_out)
     else:
-        _res = execute_cmd(cmd_text, encoding=None, level=None)
+        _res = execute_cmd(cmd_text, encoding=None, level=None, timeout=timeout)
         out_decode = bytes_to_str(_res.stdout)
 
     _app_list = []
@@ -188,13 +188,13 @@ def get_current_app_list(detail=False, win_rm_session=None) -> list:
     return _app_list
 
 
-def kill_pid(pid: int, force: bool = False):
+def kill_pid(pid: int, force: bool = False, timeout: int = 60):
     """kill指定进程"""
     cmd_text = f"taskkill /pid {pid} /t"
     if force:
         cmd_text += " /F"
     try:
-        _res = execute_cmd(cmd_text, encoding="GBK")
+        _res = execute_cmd(cmd_text, encoding="GBK", timeout=timeout)
     except ExecuteCMDException as _e:
         if "没有找到进程" in str(_e):
             pass
@@ -202,13 +202,13 @@ def kill_pid(pid: int, force: bool = False):
             logger.error(_e)
 
 
-def kill_process(name: str, force: bool = False):
+def kill_process(name: str, force: bool = False, timeout: int = 60):
     """kill指定进程"""
     cmd_text = f"taskkill /im {name} /t"
     if force:
         cmd_text += " /F"
     try:
-        _res = execute_cmd(cmd_text, encoding="GBK")
+        _res = execute_cmd(cmd_text, encoding="GBK", timeout=timeout)
     except ExecuteCMDException as _e:
         if "没有找到进程" in str(_e):
             pass
